@@ -3,7 +3,7 @@
 // Purpose:    Accelerators and shortcuts
 // Part of:    4Pane
 // Author:     David Hart
-// Copyright:  (c) 2016 David Hart
+// Copyright:  (c) 2019 David Hart
 // Licence:    wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
 
@@ -229,7 +229,7 @@ const wxString DefaultMenuLabels[] = {
   _("Go to Symlink Target"),_("Go to Symlink Ultimate Target"),_("Edit"),_("New Separator"), _("Repeat Previous Program"), _("Navigate to opposite pane"), _("Navigate to adjacent pane"),
   _("Switch to the Panes"), _("Switch to the Terminal Emulator"), _("Switch to the Command-line"), _("Switch to the toolbar Textcontrol"), _("Switch to the previous window"), 
   _("Go to Previous Tab"), _("Go to Next Tab"), _("Paste as Director&y Template"), _("&First dot"), _("&Penultimate dot"), _("&Last dot"),
-  _("Mount over Ssh using ssh&fs"), _("Show &Previews"), _("C&ancel Paste"), _("Decimal-aware filename sort") };
+  _("Mount over Ssh using ssh&fs"), _("Show &Previews"), _("C&ancel Paste"), _("Decimal-aware filename sort"), _("&Keep Modification-time when pasting files") };
 
 int DefaultShortcutFlags[] = { wxACCEL_CTRL, wxACCEL_CTRL, wxACCEL_NORMAL, wxACCEL_SHIFT, wxACCEL_NORMAL, wxACCEL_NORMAL, wxACCEL_CTRL,
       wxACCEL_ALT, wxACCEL_NORMAL, wxACCEL_NORMAL, wxACCEL_NORMAL, wxACCEL_CTRL, wxACCEL_CTRL+wxACCEL_SHIFT, wxACCEL_ALT+wxACCEL_SHIFT,
@@ -245,7 +245,7 @@ int DefaultShortcutFlags[] = { wxACCEL_CTRL, wxACCEL_CTRL, wxACCEL_NORMAL, wxACC
       wxACCEL_NORMAL, wxACCEL_NORMAL, wxACCEL_NORMAL, wxACCEL_ALT, wxACCEL_NORMAL, wxACCEL_NORMAL, wxACCEL_NORMAL, wxACCEL_NORMAL, wxACCEL_CTRL,
       wxACCEL_NORMAL, wxACCEL_NORMAL,wxACCEL_NORMAL, wxACCEL_NORMAL, wxACCEL_NORMAL, wxACCEL_CTRL+wxACCEL_SHIFT, wxACCEL_CTRL+wxACCEL_SHIFT,
       wxACCEL_NORMAL, wxACCEL_NORMAL, wxACCEL_NORMAL, wxACCEL_NORMAL, wxACCEL_NORMAL,
-      wxACCEL_CTRL+wxACCEL_SHIFT, wxACCEL_CTRL+wxACCEL_SHIFT, wxACCEL_NORMAL, wxACCEL_NORMAL, wxACCEL_NORMAL, wxACCEL_NORMAL, wxACCEL_NORMAL, wxACCEL_CTRL, wxACCEL_SHIFT, wxACCEL_NORMAL };
+      wxACCEL_CTRL+wxACCEL_SHIFT, wxACCEL_CTRL+wxACCEL_SHIFT, wxACCEL_NORMAL, wxACCEL_NORMAL, wxACCEL_NORMAL, wxACCEL_NORMAL, wxACCEL_NORMAL, wxACCEL_CTRL, wxACCEL_SHIFT, wxACCEL_NORMAL, wxACCEL_NORMAL };
 
 int DefaultShortcutKeycode[] = { 'X', 'C', WXK_DELETE,WXK_DELETE,0, WXK_F2, 'D', // 7 entries
                               'P', 0, 0, 0, 'V', 'L', 'L',                       // 7
@@ -261,7 +261,7 @@ int DefaultShortcutKeycode[] = { 'X', 'C', WXK_DELETE,WXK_DELETE,0, WXK_F2, 'D',
                               0, 0, 0, WXK_F4, WXK_F1, 0, 0, 0, 'S',             // 9
                               0, 0, 0, 0, 0, 'O','A',                            // 7
                               0, 0, 0, 0, 0,                                     // 5
-                               ',', '.', 0, 0, 0, 0 , 0, 'P', WXK_ESCAPE, 0 };   // 10
+                               ',', '.', 0, 0, 0, 0 , 0, 'P', WXK_ESCAPE, 0, 0 }; // 11
 
 const wxString DefaultMenuHelp[] = { 
   _("Cuts the current selection"), _("Copies the current selection"), _("Send to the Trashcan"), _("Kill, but may be resuscitatable"),_("Delete with extreme prejudice"), wxT(""), wxT(""),
@@ -279,7 +279,7 @@ _("Delete the currently-selected Tab"), _("Rename the currently-selected Tab"),
   wxT(""),wxT(""), wxT(""), wxT(""), wxT(""), wxT(""), 
   wxT(""), wxT(""), wxT(""), wxT(""), wxT(""),
   wxT(""), wxT(""), _("Paste only the directory structure from the clipboard"),_("An ext starts at first . in the filename"), _("An ext starts at last or last-but-one . in the filename"), _("An ext starts at last . in the filename"),
-  wxT(""), _("Show previews of image and text files"), _("Cancel the current process"), _("Should files like foo1, foo2 be in Decimal order") };
+  wxT(""), _("Show previews of image and text files"), _("Cancel the current process"), _("Should files like foo1, foo2 be in Decimal order"), _("Should a Moved or Pasted file keep its original modification time (as in 'cp -a')") };
                               
 const size_t SHCUTno = sizeof(DefaultShortcutKeycode)/sizeof(int);
 
@@ -482,7 +482,7 @@ int archiveitems[] = { SHCUT_ARCHIVE_EXTRACT, wxID_SEPARATOR, SHCUT_ARCHIVE_CREA
 
 
 int toolsitems[] = { SHCUT_TOOL_LOCATE, SHCUT_TOOL_FIND, SHCUT_TOOL_GREP, wxID_SEPARATOR, SHCUT_LAUNCH_TERMINAL };
-int optionsitems[] = { ID_CHECKNEXTITEM, SHCUT_SHOW_RECURSIVE_SIZE, ID_CHECKNEXTITEM, SHCUT_RETAIN_REL_TARGET, wxID_SEPARATOR, SHCUT_SAVETABS, ID_CHECKNEXTITEM,SHCUT_SAVETABS_ONEXIT, wxID_SEPARATOR, SHCUT_EMPTYTRASH, SHCUT_EMPTYDELETED, wxID_SEPARATOR, SHCUT_CONFIGURE };
+int optionsitems[] = { ID_CHECKNEXTITEM, SHCUT_SHOW_RECURSIVE_SIZE, ID_CHECKNEXTITEM, SHCUT_RETAIN_REL_TARGET, ID_CHECKNEXTITEM, SHCUT_RETAIN_MTIME_ON_PASTE, wxID_SEPARATOR, SHCUT_SAVETABS, ID_CHECKNEXTITEM, SHCUT_SAVETABS_ONEXIT, wxID_SEPARATOR, SHCUT_EMPTYTRASH, SHCUT_EMPTYDELETED, wxID_SEPARATOR, SHCUT_CONFIGURE };
 int helpitems[] = { SHCUT_HELP, SHCUT_FAQ, wxID_SEPARATOR, SHCUT_ABOUT };
 
 int columnitems[] = { ID_CHECKNEXTITEM,SHCUT_SHOW_COL_EXT, ID_CHECKNEXTITEM,SHCUT_SHOW_COL_SIZE, ID_CHECKNEXTITEM,SHCUT_SHOW_COL_TIME,
@@ -882,21 +882,10 @@ if (event.GetId() == XRCID("UDSApply"))                          // If it's an O
         wxNotifyEvent event(MyReloadAcceleratorsEvent);          // Send a custom event, eventually to MyFrame, to tell it to update menus, accel tables
         wxPostEvent(wxTheApp->GetTopWindow(), event);
       }
-
-#if defined(__WXGTK20__)
-    if (FromNotebook && USE_F10_KEY != F10check->IsChecked())
-      { USE_F10_KEY = F10check->IsChecked();                     // In gtk2 only, allow/prevent F10 from being grabbed to open the File menu
-        wxConfigBase::Get()->Write(wxT("/Misc/Misc/UseF10Key"), USE_F10_KEY);
-      }
-#endif
   }
  else
   if (FromNotebook)
-    { Init(AL, FromNotebook);                                   // Cancel needs to redo the listctrl as the dialog will remain visible
-#if defined(__WXGTK20__)
-      F10check->SetValue(USE_F10_KEY);                          // as this doesn't get done in Init()
-#endif
-    }
+    { Init(AL, FromNotebook); }                                  // Cancel needs to redo the listctrl as the dialog will remain visible
 
 WX_CLEAR_ARRAY(Temparray);
 AL->dirty = false;
