@@ -3,7 +3,7 @@
 // Purpose:    Non-virtual archive stuff
 // Part of:    4Pane
 // Author:     David Hart
-// Copyright:  (c) 2016 David Hart
+// Copyright:  (c) 2019 David Hart
 // Licence:    GPL v3
 /////////////////////////////////////////////////////////////////////////////
 #include "wx/wxprec.h" 
@@ -82,19 +82,23 @@ if ((c = archivename.Find(wxT(".tar."))) != -1)     // If this is a tar.?z(2) ar
   UncompressedName = archivename.Left(c + 4);       //   remove the .?z(2), keeping the .tar
  else
    { if (archivename.Right(3) == wxT(".7z")) return wxT(""); // A standard (non-tar) 7z is an archive, but not as we know it
-      else                                          // Otherwise it must have a .t?z ext
-        UncompressedName = archivename.BeforeLast(wxT('.')) + wxT(".tar");  // Replace this with tar
+      else
+       { if (archivename.Right(4) == wxT(".rar")) return wxT(""); // Ditto for rar
+          else                                          // Otherwise it must have a .t?z ext
+            UncompressedName = archivename.BeforeLast(wxT('.')) + wxT(".tar");  // Replace this with tar
+       }
    }
 
 return UncompressedName;
 }
 
 //static
-bool ArchiveDialogBase::IsAnArchive(const wxString& filename)    // Decide if the file is an archive suitable for appending to
+bool ArchiveDialogBase::IsAnArchive(const wxString& filename, bool append/*=false*/)    // Decide if the file is an archive suitable for extracting +/- appending to
 {
 wxString ext = filename.AfterLast('.'); ext.MakeLower();    // See if the last .ext is relevant
 if (ext==wxT("tar") || ext==wxT("tgz") || ext==wxT("tbz2") || ext==wxT("tbz") || ext==wxT("lzma") || ext==wxT("tlz")
   || ext==wxT("a") || ext==wxT("ar") || ext==wxT("cpio") || ext==wxT("rpm") || ext==wxT("deb")
+  || (ext=="rar" && !append) // We can extract a .rar using the (free-ish) 'unrar' but can't append to one
   || ext==wxT("7z")                                         // All 7z's are archives
   || ext==wxT("zip") || ext==wxT("htb"))
   return true;
@@ -187,7 +191,7 @@ size_t count = m_parent->FilepathArray.GetCount();
 for (size_t n=0; n < count; ++n)                               // & the listbox
   if (!(m_parent->FilepathArray[n]==m_parent->active->GetActiveDirectory() && count==1))  // We don't want rootdir in the list just because it's automatically highlit
     { if (!(NewArchive || foundarchive)) // If we're appending, see if we can spot an archive name to append to (if we haven't found one already)
-        { if (IsAnArchive(m_parent->FilepathArray[n]))         //  See if the file is an archive suitable for appending to
+        { if (IsAnArchive(m_parent->FilepathArray[n], true))        // See if the file is an archive suitable for appending to
             { createincombo->SetValue(m_parent->FilepathArray[n]);  // If so, put it in the archive filepath combobox
               foundarchive = true;
             }
@@ -685,7 +689,7 @@ if (event.GetId() == XRCID("wxID_OK")) // Enable the OK button if >0 files in li
 
 enum returntype DecompressDialog::GetCommand()  // Parse entered options into a command
 {
-wxString command; wxArrayString gz, bz, xz, sevenz, lzo;
+wxString command; wxArrayString gz, bz, xz, sevenz, rar, lzo;
 
 if (!list->GetCount()) return cancel;                   // Shouldn't happen, as Return would be disabled
 
@@ -1010,6 +1014,9 @@ switch(ztype)
                 command << wxT(" && ") << helper.GetData();
                 break;
                 }
+    case zt_rar: if (!Configure::TestExistence("unrar")) { wxMessageBox(_("Can't find unrar on your system..."), _("Oops"), wxOK, this); return cancel; }
+                command << wxString::Format("echo Extracting %s && ", archivename) << "(cd \\\"" << createindir
+                        << "\\\" && unrar x \\\"" << archive <<  "\\\")"; break;
 
     default:    wxMessageDialog dialog(this, _("Can't find a valid archive to extract.\nTry again?"), wxT(""), wxYES_NO | wxICON_QUESTION);
                 if (dialog.ShowModal() == wxID_YES)  return retry; else return cancel;
@@ -1157,6 +1164,9 @@ switch(m_parent->Categorise(archivefilepath))
             command << wxT("cpio -t ") << wxT("-I \\\"") << archivefilepath << wxT("\\\""); break;
     case zt_ar:
             command << wxString::Format(wxT("echo Verifying %s && "), archivename.c_str()) << wxT("ar tv \\\"") << archivefilepath <<  wxT("\\\""); break;
+    case zt_rar:
+            if (!Configure::TestExistence("unrar")) { wxMessageBox(_("Can't find unrar on your system..."), _("Oops"), wxOK, this); return cancel; }
+            command << wxString::Format("echo Verifying %s && ", archivename.c_str()) << "unrar t \\\"" << archivefilepath <<  "\\\""; break;
     case zt_deb:
             command << wxString::Format(wxT("echo Verifying %s && "), archivename.c_str())
                     << wxT("ar p \\\"") << archivefilepath <<  wxT("\\\" control.tar.gz | tar -ztv && ")
@@ -1323,8 +1333,9 @@ if (endExt==wxT("zip"))  return zt_zip;
 if (endExt==wxT("tar"))                                                 return zt_taronly;
 if (endExt==wxT("cpio"))                                                return zt_cpio;
 if (endExt==wxT("rpm"))                                                 return zt_rpm;  // which we're treating as an archive
-if (endExt==wxT("deb"))                                                 return zt_deb;  //   ""
+if (endExt==wxT("deb")  || endExt==wxT("ddeb"))                         return zt_deb;  // ditto (and debian now labels debug debs 'ddeb')
 if (endExt==wxT("ar")   || endExt==wxT("a"))                            return zt_ar;
+if (endExt=="rar")                                                      return zt_rar;
 
 if (endExt==wxT("tgz")  || (prevExt==wxT("tar") && endExt==wxT("gz")))  return zt_targz;
 if (endExt==wxT("tbz2") || endExt==wxT("tbz"))                          return zt_tarbz;
