@@ -127,9 +127,10 @@ struct DevicesStruct   // Holds data for a device
   };
 
 struct PartitionStruct  // Holds possible partitions, mountpts, mount status
-  { wxString device;              // Holds eg /dev/hda2
+  { wxString device;              // Holds eg /dev/sda2
     wxString type;                // e.g. ext4 or swap. Used (iiuc) to avoid displaying swap partitions when not using lsblk
     wxString uuid;                // Holds the uuid for the device, for use when /etc/fstab is uuid-based
+    wxString label;               // Similarly for mounting by label
     wxString mountpt;             // Holds fstab's mountpt for this device
     bool IsMounted;     
   };
@@ -257,8 +258,8 @@ void OnMountSshfs();
 void OnMountSamba();
 void OnUnMountNetwork();
 static struct mntent* ReadMtab(const wxString& partition, bool DvdRamFS=false); // Goes thru mtab, to find if 'partition' currently mounted. If DvdRamFS, ignores eg subfs mounts (used for DVD-RAM)
-static struct fstab* ReadFstab(const wxString& dev, const wxString& uuid = wxT("")); // Search fstab for a line for this device
-static struct fstab* ReadFstab(const PartitionStruct* ps) { return ReadFstab(ps->device, ps->uuid); }
+static struct fstab* ReadFstab(const wxString& dev, const wxString& uuid = "", const wxString& label = ""); // Search fstab for a line for this device
+static struct fstab* ReadFstab(const PartitionStruct* ps) { return ReadFstab(ps->device, ps->uuid, ps->label); }
 static bool FindUnmountedFstabEntry(wxString& dev, wxArrayString& answerarray); // Ditto but only returning Unmounted entries.  Used for DVD-RAM
 size_t ReadFstab(ArrayofPartitionStructs& PartitionArray, const wxString& type) const; // Uses findmnt to look for entries of a particular type or types e.g. cifs
 static void LoadFstabEntries(wxArrayString& devicenodes, wxArrayString& mountpts);  // Loads all valid fstab entries into arrays
