@@ -15,7 +15,8 @@
   #define __GNU_HURD__
   enum TranslatorType { TT_active, TT_passive, TT_either };
 #endif
-
+extern bool SvgToPng(const wxString& svgfilepath, const wxString& outputfilepath, void* dlhandle); // Renders an svg file to an image
+extern wxString LocateLibrary(const wxString& lib); // Search ldconfig output to find a lib's filepath. 'lib' can/will be a partial name e.g. 'rsvg'
 
 extern wxString HOME;             // In case we want to pass as a parameter an alternative $HOME
                                   // Externs for some global functions
@@ -40,6 +41,7 @@ extern void QuoteExcludingWildcards(wxString& command);           // Wraps comma
 extern void SetSortMethod(const bool LC_COLLATE_aware);           // Do we want filename etc sorting to be LC_COLLATE aware?
 extern void SetDirpaneSortMethod(const bool LC_COLLATE_aware);    // Ditto for dirpane sorting
 extern wxString TruncatePathtoFitBox(wxString filepath, wxWindow* box); // In Misc, used by MyFiles
+extern wxWindow* InsertEllipsizingStaticText(wxString filepath, wxWindow* original, int insertAt = -1); // In Misc, used by MyFiles and MyDirs
 extern wxString MakeTempDir(const wxString& name = wxT(""));      // In Misc, Makes a unique dir in /tmp/4Pane/
 extern wxBitmap GetBestBitmap(const wxArtID& artid, const wxArtClient& client, const wxBitmap& fallback_xpm); // In Misc, returns a wxArtProvider bitmap or the default one
 extern void QueryWrapWithShell(wxString& command);                //  In Misc. Wraps command with sh -c if appropriate
@@ -88,10 +90,6 @@ extern wxString HELPDIR;
 
 extern wxWindowID NextID;
 
-#if defined(__WXGTK20__)
-  extern bool USE_F10_KEY;
-#endif
-
 extern wxFont TREE_FONT;         // Which font is currently used in the panes
 extern wxFont CHOSEN_TREE_FONT;  // Which font to use in the panes if USE_DEFAULT_TREE_FONT is false
 extern bool USE_DEFAULT_TREE_FONT;
@@ -122,6 +120,7 @@ extern bool GNOME_TERM_PRESENT;
 extern bool XTERM_PRESENT;
 extern bool XCFE4_PRESENT;
 extern bool LXTERMINAL_PRESENT;
+extern bool QTERMINAL_PRESENT;
 extern bool MATETERMINAL_PRESENT;
 extern wxString TERMINAL;        // The name of the terminal for terminal sessions.  Default "konsole"
 extern wxString TERMINAL_COMMAND; // Command to prepend to an applic to launch in terminal window.  Default "xterm -e"
@@ -147,6 +146,7 @@ extern const bool ISRIGHT;        //  as opposed to a file window
 
 extern bool SHOW_RECURSIVE_FILEVIEW_SIZE;
 extern bool RETAIN_REL_TARGET;              // If we Move a relative symlink, keep the original target
+extern bool RETAIN_MTIME_ON_PASTE;          // Should Move/Paste keep the modification time of the origin file
 extern size_t MAX_NUMBER_OF_UNDOS;          // Amount of memory to allocate for UnRedo
 extern size_t MAX_NUMBER_OF_PREVIOUSDIRS;   // Similarly for previously-visited dirs
 extern size_t MAX_DROPDOWN_DISPLAY;         // How many to display at a time on a dropdown menu
@@ -330,6 +330,8 @@ enum                  //  menuitem IDs
   SHCUT_ESCAPE, // For interrupting threads
   
   SHCUT_DECIMALAWARE_SORT, // In the current fileview, sort foo1, foo2 above foo11
+  
+  SHCUT_RETAIN_MTIME_ON_PASTE, // When Moving/Pasting, try to leave the modification time ISQ (like cp -a)
 
 
   // *****
@@ -424,7 +426,7 @@ enum ConfigDeviceType { CDT_fixed = 0, CDT_removable };          // Makes it eas
 enum ziptype
  { zt_gzip, zt_bzip, zt_lzma, zt_xz, zt_lzop, zt_compress, zt_lastcompressed = zt_compress,
    zt_firstarchive, zt_taronly = zt_firstarchive, zt_cpio, zt_rpm, zt_ar, zt_deb,
-   zt_firstcompressedarchive, zt_targz = zt_firstcompressedarchive, zt_tarbz, zt_tarlzma, zt_tarxz, zt_tar7z, zt_tarlzop, zt_taZ, zt_7z, zt_zip, zt_htb, zt_lastcompressedarchive = zt_htb,
+   zt_firstcompressedarchive, zt_targz = zt_firstcompressedarchive, zt_tarbz, zt_tarlzma, zt_tarxz, zt_tar7z, zt_tarlzop, zt_taZ, zt_7z, zt_zip, zt_rar, zt_htb, zt_lastcompressedarchive = zt_htb,
    zt_invalid 
  };
 
