@@ -3,7 +3,7 @@
 // Purpose:    Mounting partitions
 // Part of:    4Pane
 // Author:     David Hart
-// Copyright:  (c) 2016 David Hart
+// Copyright:  (c) 2019 David Hart
 // Licence:    GPL v3
 /////////////////////////////////////////////////////////////////////////////
 
@@ -239,7 +239,7 @@ int ans = dlg.ShowModal();
 SaveCurrentSize(&dlg, wxT("UnMountDlg"));
 if (ans != wxID_OK) return;
 
-wxString partition = dlg.PartitionsCombo->GetValue();
+wxString partition = dlg.PartitionsCombo->GetValue().BeforeFirst(' '); // BeforeFirst in case of "/dev/sda1  $UUID/$LABEL";
 wxString mount = dlg.FstabMountptTxt->GetValue(); 
 if (mount.IsEmpty()) return;          
 if (mount==wxT("/")) { wxMessageBox(_("Unmounting root is a SERIOUSLY bad idea!"), wxT("Tsk! Tsk!")); return; }
@@ -831,12 +831,23 @@ if (device != wxEmptyString)                                // This is if we're
 for (size_t n=0; n < parent->PartitionArray->GetCount(); ++n)
   { PartitionStruct* pstruct = parent->PartitionArray->Item(n);
     if (FstabMountptTxt == NULL)                            // If this is the 'Other' version of the dialog, load every known unmounted partition
-      { if (!pstruct->IsMounted) 
-          PartitionsCombo->Append(pstruct->device.c_str());
+      { if (!pstruct->IsMounted)
+          { wxString devicestr(pstruct->device);
+            if (!pstruct->label.empty()) devicestr << " " << pstruct->label;
+            PartitionsCombo->Append(devicestr);
+          }
       }
      else
       { if (pstruct->IsMounted || pstruct->mountpt.IsEmpty()) continue;  // Ignore already-mounted partitions, or ones not in fstab (so no known mountpt)
-        PartitionsCombo->Append(pstruct->device.c_str());   // This one qualifies, so add it
+        wxString devicestr(pstruct->device);
+        if (!pstruct->label.empty()) devicestr << " " << pstruct->label;
+         else if (!pstruct->uuid.empty())
+          { wxString UUID(pstruct->uuid);
+            if (UUID.Len() > 16)
+              UUID = pstruct->uuid.BeforeFirst('-') + "..." + pstruct->uuid.AfterLast('-'); // Truncate display of standard UUIDs
+            devicestr << " " << UUID;
+          }
+        PartitionsCombo->Append(devicestr);   // This one qualifies, so add it
       }
   }
 #if (defined(__WXGTK20__) || defined(__WXX11__))
@@ -852,7 +863,7 @@ if (FstabMountptTxt == NULL) return;                        // because in the 'O
 
 wxString dev = PartitionsCombo->GetValue();                 // We need to use GetValue(), not GetStringSelection(), as in >2.6.3 the latter fails
 for (size_t n=0; n < parent->PartitionArray->GetCount(); ++n)
-  if (parent->PartitionArray->Item(n)->device == dev)
+  if (parent->PartitionArray->Item(n)->device == dev.BeforeFirst(' ')) // BeforeFirst in case of "/dev/sda1  $UUID/$LABEL"
     { if (GetDataFromMtab)    // If we're unmounting, we can't rely on the PartitionArray info:  the partition may not have been mounted where fstab intended
         { FstabMountptTxt->Clear();
           struct mntent* mnt = parent->ReadMtab(dev);       // So see where it really is
@@ -1680,7 +1691,16 @@ for (size_t n=0; n < parent->PartitionArray->GetCount(); ++n)
   { PartitionStruct* pstruct = parent->PartitionArray->Item(n);
     if (pstruct->IsMounted && !pstruct->mountpt.IsEmpty()           // Ignore unmounted partitions
                            && !(pstruct->mountpt == wxT("/")))      // Filter out root too; we don't want to be umounted ourselves
-        PartitionsCombo->Append(pstruct->device.c_str());
+      { wxString devicestr(pstruct->device);
+        if (!pstruct->label.empty()) devicestr << " " << pstruct->label;
+         else if (!pstruct->uuid.empty())
+          { wxString UUID(pstruct->uuid);
+            if (UUID.Len() > 16)
+              UUID = pstruct->uuid.BeforeFirst('-') + "..." + pstruct->uuid.AfterLast('-'); // Truncate display of standard UUIDs
+            devicestr << " " << UUID;
+          }
+        PartitionsCombo->Append(devicestr);
+      }
   }
 
 #if (defined(__WXGTK20__) || defined(__WXX11__))
