@@ -3,7 +3,7 @@
 // Purpose:    File-view
 // Part of:    4Pane
 // Author:     David Hart
-// Copyright:  (c) 2016 David Hart
+// Copyright:  (c) 2019 David Hart
 // Licence:    GPL v3
 /////////////////////////////////////////////////////////////////////////////
 
@@ -1036,7 +1036,15 @@ manager.OpenWith();
 
 }
 
-void FileGenericDirCtrl::UpdateStatusbarInfo(const wxString& selected)  // Writes filter info to statusbar(3), &  selection's name & size (or whatever) to statusbar(2)
+void FileGenericDirCtrl::UpdateStatusbarInfo(const wxString& selected)  // Feeds the other overload with a wxArrayString if called with a single selection
+{
+if (!selected.empty())
+  { wxArrayString arr; arr.Add(selected);
+    UpdateStatusbarInfo(arr);
+  }
+}
+
+void FileGenericDirCtrl::UpdateStatusbarInfo(const wxArrayString& selections)  // Writes filter info to statusbar(3), &  selections' names/size (or whatever) to statusbar(2)
 {
                             // First the filter info into the 4th statusbar pane
 wxString filterinfo, start, filter = GetFilterString(); if (filter.IsEmpty())  filter = wxT("*");  // Translate "" into "*"
@@ -1046,52 +1054,101 @@ start += (GetShowHidden() ? _(" H     ") : wxT("     "));     // Add whether we'
 filterinfo.Printf(wxT("%s%s"),start.c_str(), filter.c_str()); // Merge into message string, adding the current filter
 MyFrame::mainframe->SetStatusText(filterinfo, 3); 
 
-if (selected.IsEmpty()) 
+if (selections.IsEmpty()) 
   { MyFrame::mainframe->SetStatusText(wxT(""), 2); return; }  // Nothing to display if the first-and-only focus click was on a blank line
 
 wxString text;
 DataBase* stat; bool IsArchive = arcman && arcman->IsArchive();
-if (IsArchive)                                                // Archives have to be treated differently
-  { FakeFiledata* fd = arcman->GetArc()->Getffs()->GetRootDir()->FindFileByName(selected);
-    if (fd != NULL)
-      { stat = new FakeFiledata(*fd);                         // We can't just make a new FakeFiledata: the size etc would be unknown; so copy the real one
-        SelectedCumSize = stat->Size();
-      }
-     else    
-      { FakeDir* fd = arcman->GetArc()->Getffs()->GetRootDir()->FindSubdirByFilepath(selected);  // If it wasn't a file, try for a dir
-        if (fd == NULL) return;
-        stat = new FakeDir(*fd);
-        if (SHOW_RECURSIVE_FILEVIEW_SIZE)   SelectedCumSize = fd->GetTotalSize();
-          else SelectedCumSize = fd->GetSize();
-      }
-  }
- else  stat = new FileData(selected);
+size_t count = selections.GetCount();
+if (!count) return;
 
-if (!stat || !stat->IsValid()) 
-  { MyFrame::mainframe->SetStatusText(wxT(""), 2); return; } 
+if (count == 1)
+  { wxString selected(selections.Item(0));
+    if (IsArchive)                                                // Archives have to be treated differently
+      { FakeFiledata* fd = arcman->GetArc()->Getffs()->GetRootDir()->FindFileByName(selected);
+        if (fd)
+          { stat = new FakeFiledata(*fd);                         // We can't just make a new FakeFiledata: the size etc would be unknown; so copy the real one
+            SelectedCumSize = stat->Size();
+          }
+         else    
+          { FakeDir* fd = arcman->GetArc()->Getffs()->GetRootDir()->FindSubdirByFilepath(selected);  // If it wasn't a file, try for a dir
+            if (!fd) return;
+            stat = new FakeDir(*fd);
+            if (SHOW_RECURSIVE_FILEVIEW_SIZE)   SelectedCumSize = fd->GetTotalSize();
+              else SelectedCumSize = fd->GetSize();
+          }
+      }
+     else  stat = new FileData(selected);
 
-if (!stat->IsSymlink())
-  { text.Printf(wxT("%s:  %s"), stat->TypeString().c_str(), selected.AfterLast(wxFILE_SEP_PATH).c_str());
-    if (m_StatusbarInfoValid) 
-      { text += wxString::Format(wxT("   %s"), ParseSize(SelectedCumSize, true).c_str());
-        if (stat->IsDir()) text += wxString::Format(wxT("%s"), SHOW_RECURSIVE_FILEVIEW_SIZE ? _("  of files and subdirectories") : _(" of files"));
+    if (!stat || !stat->IsValid()) 
+      { MyFrame::mainframe->SetStatusText(wxT(""), 2); return; } 
+
+    if (!stat->IsSymlink())
+      { text.Printf(wxT("%s:  %s"), stat->TypeString().c_str(), selected.AfterLast(wxFILE_SEP_PATH).c_str());
+        if (m_StatusbarInfoValid) 
+          { text += wxString::Format(wxT("   %s"), ParseSize(SelectedCumSize, true).c_str());
+            if (stat->IsDir()) text += wxString::Format(wxT("%s"), SHOW_RECURSIVE_FILEVIEW_SIZE ? _("  of files and subdirectories") : _(" of files"));
+          }
+      }
+     else
+      { text.Printf(wxT("%s:  %s"), stat->TypeString().c_str(), selected.AfterLast(wxFILE_SEP_PATH).c_str()); // If possible, add the symlink target
+        if (stat->IsFake)
+          { if (!stat->GetSymlinkDestination().IsEmpty()) 
+              { wxString target; target.Printf(wxT("  --> %s"), stat->GetSymlinkDestination(true).c_str()); text << target; }
+          }
+          else
+           if (stat->GetSymlinkData())
+            { wxString target(wxT("  --> ")); size_t len = target.Len(); // Store length without target
+              if (stat->GetSymlinkData()->IsValid()) 
+                target << stat->GetSymlinkDestination(true);      // 'true' says to display relative symlinks as relative
+               else  target << ((FileData*)stat)->GetSymlinkData()->BrokenlinkName;  // If !IsValid, display any known broken-link name
+              if (target.Len() > len)                             // See if we've successfully appended a target i.e. added something to "  --> "
+                text << target;                                   // If so, use it
+            }
       }
   }
  else
-  { text.Printf(wxT("%s:  %s"), stat->TypeString().c_str(), selected.AfterLast(wxFILE_SEP_PATH).c_str()); // If possible, add the symlink target
-    if (stat->IsFake)
-      { if (!stat->GetSymlinkDestination().IsEmpty()) 
-          { wxString target; target.Printf(wxT("  --> %s"), stat->GetSymlinkDestination(true).c_str()); text << target; }
-      }
-      else
-       if (stat->GetSymlinkData())
-        { wxString target(wxT("  --> ")); size_t len = target.Len(); // Store length without target
-          if (stat->GetSymlinkData()->IsValid()) 
-            target << stat->GetSymlinkDestination(true);      // 'true' says to display relative symlinks as relative
-           else  target << ((FileData*)stat)->GetSymlinkData()->BrokenlinkName;  // If !IsValid  store any known broken-link name
-          if (target.Len() > len)                             // See if we've successfully appended a target i.e. added something to "  --> "
-            text << target;                                   // If so, use it
+  { size_t failures(0), dirs(0), files(0);
+    if (IsArchive) SelectedCumSize = 0;
+    for (size_t n=0; n < count; ++n)
+    { wxString selected(selections.Item(n));
+      if (IsArchive)                                                // Archives have to be treated differently
+        { FakeFiledata* fd = arcman->GetArc()->Getffs()->GetRootDir()->FindFileByName(selected);
+          if (fd)
+            { stat = new FakeFiledata(*fd);                         // We can't just make a new FakeFiledata: the size etc would be unknown; so copy the real one
+              SelectedCumSize += stat->Size();
+            }
+           else    
+            { FakeDir* fd = arcman->GetArc()->Getffs()->GetRootDir()->FindSubdirByFilepath(selected);  // If it wasn't a file, try for a dir
+              if (!fd) return;
+              stat = new FakeDir(*fd);
+              if (SHOW_RECURSIVE_FILEVIEW_SIZE)   SelectedCumSize += fd->GetTotalSize();
+                else SelectedCumSize += fd->GetSize();
+            }
         }
+       else  stat = new FileData(selected);
+
+      if (!stat || !stat->IsValid()) { ++failures; continue; }
+
+      if (stat->IsDir()) ++dirs;
+        else ++files;
+    }
+
+    if (failures < count)
+      { 
+        if (SHOW_RECURSIVE_FILEVIEW_SIZE && dirs)
+          text = wxString::Format(_("%s in %zu %s"), ParseSize(SelectedCumSize, true), count, _("files and directories"));
+         else
+          { text = wxString::Format("%s", ParseSize(SelectedCumSize, true));
+            wxString DirOrDirs = (dirs>1 ? _("directories"):_("directory"));
+            wxString FileOrFiles = (files>1 ? _("files"):_("file"));
+            if (dirs && files) text << wxString::Format(_(" in %zu %s and %zu %s"), dirs, DirOrDirs, files, FileOrFiles);
+             else
+               { if (dirs) text << wxString::Format(_(" in %zu %s"), dirs, DirOrDirs);
+                  else text << wxString::Format(_(" in %zu %s"), files, FileOrFiles);
+               }
+          }
+      }
   }
 
 MyFrame::mainframe->SetStatusText(text, 2); 
@@ -1330,9 +1387,12 @@ switch(headerwindow->GetSelectedColumn())                               // Since
 
 void FileGenericDirCtrl::SelectFirstItem()
 {
-wxTreeItemIdValue cookie;
-wxTreeItemId firstId = GetTreeCtrl()->GetFirstChild(GetRootId(), cookie);
-if (firstId.IsOk())  GetTreeCtrl()->SelectItem(firstId);
+wxTreeItemId rootId = GetTreeCtrl()->GetRootItem();
+if (rootId.IsOk())
+  { wxTreeItemIdValue cookie;
+    wxTreeItemId firstId = GetTreeCtrl()->GetFirstChild(GetTreeCtrl()->GetRootItem(), cookie);
+    if (firstId.IsOk())  GetTreeCtrl()->SelectItem(firstId);
+  }
 }
 
 bool FileGenericDirCtrl::UpdateTreeFileModify(const wxString& filepath) // Called when a wxFSW_EVENT_MODIFY arrives
@@ -1469,7 +1529,7 @@ if (!stat->IsSymlink()) wxXmlResource::Get()->LoadDialog(&dlg, MyFrame::mainfram
   { if (stat->IsSymlinktargetASymlink())
        { wxXmlResource::Get()->LoadDialog(&dlg, MyFrame::mainframe, wxT("UltSymlinkPropertiesDlg")); // The multiple-symlink version has 2 extra sections
         wxTextCtrl* UltTarget = (wxTextCtrl*)dlg.FindWindow(wxT("UltLinkTargetText"));
-        UltTarget->SetValue(TruncatePathtoFitBox(stat->GetUltimateDestination(), UltTarget));  // Put the ultimate target filepath into its textctrl
+        UltTarget->SetValue(stat->GetUltimateDestination());
         dlg.Connect(XRCID("UltLinkTargetBtn"), wxEVT_COMMAND_BUTTON_CLICKED, (wxObjectEventFunction)&MyGenericDirCtrl::OnLinkTargetButton);
       }
      else    wxXmlResource::Get()->LoadDialog(&dlg, MyFrame::mainframe, wxT("SymlinkPropertiesDlg")); // The Symlink version has 1 extra section
@@ -1484,7 +1544,8 @@ wxTextCtrl* Name = (wxTextCtrl*)dlg.FindWindow(wxT("Name")); Name->SetValue(stat
 
 wxStaticText* Path = (wxStaticText*)dlg.FindWindow(wxT("Path"));
 wxString path = filepaths[0].BeforeLast(wxFILE_SEP_PATH) + wxFILE_SEP_PATH;
-Path->SetLabel(TruncatePathtoFitBox(path, Path));       // Most paths are too big for the Path static, so check first, truncate if needed
+Path = dynamic_cast<wxStaticText*>(InsertEllipsizingStaticText(path, Path)); // Most paths are too big for the Path static, so use an elipsizing statictext
+wxCHECK_RET(Path, "InsertEllipsizingStaticText() failed");
 
 wxTextCtrl* UserText = (wxTextCtrl*)dlg.FindWindow(wxT("UserText"));
 wxComboBox* UserCombo = (wxComboBox*)dlg.FindWindow(wxT("UserCombo"));
@@ -1624,12 +1685,12 @@ do
                 if (dialog.ShowModal() == wxID_YES) continue;   // Try again
               }
              else
-              { wxString currentfilepath = stat->GetFilepath(), oldtarget = stat->GetSymlinkDestination(true); 
+              { wxString currentfilepath = stat->GetFilepath(), oldtarget = stat->GetSymlinkDestination(true);
                 bool result = CheckDupRen::ChangeLinkTarget(currentfilepath, dest);
                 if (!result) wxMessageBox(_("For some reason, changing the symlink's target seems to have failed.  Sorry!"));
                   else
                     { wxArrayInt IDs; IDs.Add(GetId());
-                      MyFrame::mainframe->OnUpdateTrees(currentfilepath, IDs);
+                      MyFrame::mainframe->OnUpdateTrees(currentfilepath, IDs, "", true); // 'true' forces a refresh in case the symlink icon needs to change to/from broken
 
                       UnRedoChangeLinkTarget *UnRedoptr = new UnRedoChangeLinkTarget(currentfilepath, IDs, dest, oldtarget);
                       UnRedoManager::AddEntry(UnRedoptr);
