@@ -89,11 +89,13 @@ void SetEscapeKeycode(int code) { m_EscapeCode = code; }
 void SetEscapeKeyFlags(int flags) { m_EscapeFlags = flags; }
 int GetEscapeKeycode() const { return m_EscapeCode; }
 int GetEscapeKeyFlags() const { return m_EscapeFlags; }
+void* GetRsvgHandle() const { return m_dlRsvgHandle; }
+void SetRsvgHandle(void* handle) { m_dlRsvgHandle = handle; }
 
 private:
 virtual bool OnInit();
 int OnExit();
-bool ParseCmdline();
+int ParseCmdline();
 int FilterEvent(wxEvent& event);
 void SetWaylandSession(bool session_type) { m_WaylandSession = session_type; }
 #if defined(__WXX11__)  && wxVERSION_NUMBER < 2800
@@ -120,6 +122,7 @@ wxString m_home; // In case we want to pass as a parameter an alternative $HOME,
 int m_EscapeCode;
 int m_EscapeFlags;
 bool m_WaylandSession;
+void* m_dlRsvgHandle;
 };
 
 DECLARE_APP(MyApp)
@@ -285,9 +288,9 @@ void Setup();                        // Does the splitting work
 void OnCommandLine();
 void ShowHideCommandLine();          // If it's showing, hide it; & vice versa
 
-void DoTool(enum toolchoice whichtool);  // Invoke the requested tool in the bottom panel
+void DoTool(enum toolchoice whichtool, bool FromSetup = false);  // Invoke the requested tool in the bottom panel
 void CloseBottom();                  // Called to return from DoTool()
-bool ShowBottom();                   // If bottompanel isn't visible, show it
+bool ShowBottom(bool FromSetup = false); // If bottompanel isn't visible, show it
 void UnShowBottom();                 // If bottompanel is visible, unsplit it
 void OnChangeDir(const wxString& newdir, bool ReusePrompt = true);  // Change terminal/commandline prompt, and perhaps titlebar, when cd entered or the dirview selection changes
 void OnUnsplit(wxSplitterEvent& event);
@@ -464,6 +467,7 @@ void OnBookmark(wxCommandEvent& event);
 
 void ToggleFileviewSizetype(wxCommandEvent& event);
 void ToggleRetainRelSymlinkTarget(wxCommandEvent& event);
+void ToggleRetainMtimeOnPaste(wxCommandEvent& event);
 void OnConfigure(wxCommandEvent& event);
 void OnConfigureShortcuts(wxCommandEvent& event);
 void OnShowBriefMessageBox(wxCommandEvent& event);
