@@ -367,7 +367,8 @@ int Rename(wxString& path, wxString& origname, wxString& newname, bool ItsADir,
 
 
 void OnIdle(wxIdleEvent& event);                       // // Checks whether we need to update the statusbar with e.g. size of selection?
-virtual void UpdateStatusbarInfo(const wxString& selected){} // In derived classes, writes the selection's name & some relevant data in the statusbar
+virtual void UpdateStatusbarInfo(const wxString& selected){} // In derived classes, calls the following overload
+virtual void UpdateStatusbarInfo(const wxArrayString& selections){} // In derived classes, writes the selection's name & some relevant data in the statusbar
 bool m_StatusbarInfoValid;                             // // If true, the statusbar size info etc is up-to-date
       // -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 private:
