@@ -5,7 +5,7 @@
 // See:        http://wxcode.sourceforge.net/components/treelistctrl/
 // Part of:    4Pane
 // Author:     David Hart
-// Copyright:  (c) 2016 David Hart
+// Copyright:  (c) 2019 David Hart
 // Licence:    GPL v3
 /////////////////////////////////////////////////////////////////////////////
 
@@ -976,6 +976,9 @@ if (!lastItem.IsOk()) return;
 wxGenericTreeItem* last = (wxGenericTreeItem*)lastItem.m_pItem;
 
 SelectItemRange(first, last);
+
+wxArrayString selections; static_cast<MyGenericDirCtrl*>(parent)->GetMultiplePaths(selections);
+static_cast<FileGenericDirCtrl*>(parent)->UpdateStatusbarInfo(selections); // Update the statusbar info
 }
 
 void MyTreeCtrl::OnReceivingFocus(wxFocusEvent& event)  // This tells grandparent window which of the 2 twin-ctrls is the one to consider active
@@ -984,14 +987,15 @@ if (!MyFrame::mainframe->SelectionAvailable) return;    // If we're constructing
 parent->ParentTab->SetActivePane(parent);               // This also stores the pane in FocusController
 
 wxString selected = parent->GetPath();
+wxArrayString selections; static_cast<MyGenericDirCtrl*>(parent)->GetMultiplePaths(selections);
 parent->DisplaySelectionInTBTextCtrl(selected);         // Take the opportunity also to display current selection in textctrl
 MyFrame::mainframe->Layout->OnChangeDir(selected);      //  & the Terminal etc if necessary
+static_cast<MyGenericDirCtrl*>(parent)->m_StatusbarInfoValid = false;
 if (parent->fileview == ISLEFT)                         //  & in the statusbar
-  ((DirGenericDirCtrl*)parent)->UpdateStatusbarInfo(selected);
- else    ((FileGenericDirCtrl*)parent)->UpdateStatusbarInfo(selected);
+  ((DirGenericDirCtrl*)parent)->UpdateStatusbarInfo(selections);
+ else    ((FileGenericDirCtrl*)parent)->UpdateStatusbarInfo(selections);
 
-wxArrayString filepaths; ((DirGenericDirCtrl*)parent)->GetMultiplePaths(filepaths);
-((DirGenericDirCtrl*)parent)->CopyToClipboard(filepaths, true); // FWIW, copy the filepath(s) to the primary selection too
+((DirGenericDirCtrl*)parent)->CopyToClipboard(selections, true); // FWIW, copy the filepath(s) to the primary selection too
 
 if (headerwindow)
   { parent->ParentTab->SwitchOffHighlights(); // Start with a blank canvas
@@ -1499,14 +1503,13 @@ if (headerwindow->IsHidden(i)) continue;                                  // //
    }
 
   // honor text alignment
-  wxString text(wxT(""));
-  if (!stat->IsValid()) text = wxT("?");                       // // If the file is corrupt, display _something_
+  wxString text("?"); // // If the file is corrupt, display _something_
+  if (!i)                                                     // // If col 0, do it the standard way
+    text = stat->ReallyGetName();                             // // but use stat->ReallyGetName() as this is might hold a useful string even if the file is corrupt
 
-  if (!i)                                                      // // If col 0, do it the standard way
-    text = stat->ReallyGetName();                              // // but use stat->ReallyGetName() as this is might hold a useful string even if the file is corrupt
-
-     else                                                      // // The whole 'else' is mine
-    { wxDateTime time;
+   else                                                       // // The whole 'else' is mine
+    { const static time_t YEAR2038(2145916800);
+      wxDateTime time;
       if (stat && !headerwindow->IsHidden(i))
         switch(i)
         { case ext:        if (stat->IsValid())
@@ -1523,26 +1526,33 @@ if (headerwindow->IsHidden(i)) continue;                                  // //
                                               text = fname.Mid(pos+1);
                                           }
                                       }
+                                      else text.Clear(); // We don't want to display '?' just because there's no ext
                                   }
                               }
                             break;
         
           case filesize:    if (stat->IsValid()) text = stat->GetParsedSize();
                             break;
-          case modtime:     if (stat->IsValid())
-                              { time.Set(stat->ModificationTime()); text = time.Format(wxT("%x %R")); } // %x means d/m/y but arranged according to locale. %R is %H:%M
+          case modtime:     if (stat->IsValid() && stat->ModificationTime() < YEAR2038) // If it's > 2038 the datetime is highly likely to be invalid, and will assert below
+                              { time.Set(stat->ModificationTime());
+                                if (time.IsValid())
+                                  text = time.Format("%x %R"); // %x means d/m/y but arranged according to locale. %R is %H:%M
+                              }
+                             else
+                              text = "00/00/00";
                             break;
           case permissions: if (stat->IsValid()) text = stat->PermissionsToText();
                             break;
-          case owner:       if (stat->IsValid()) text = stat->GetOwner(); if (text.IsEmpty())  text.Printf(wxT("%u"),  stat->OwnerID());
+          case owner:       if (stat->IsValid()) text = stat->GetOwner(); if (text.IsEmpty())  text.Printf(wxT("%u"), stat->OwnerID());
                             break;
-          case group:       if (stat->IsValid()) text = stat->GetGroup(); if (text.IsEmpty())  text.Printf(wxT("%u"),  stat->GroupID());
+          case group:       if (stat->IsValid()) text = stat->GetGroup(); if (text.IsEmpty())  text.Printf(wxT("%u"), stat->GroupID());
                             break;
           case linkage:     if (stat->IsValid() && stat->IsSymlink())
                               { if (stat->GetSymlinkData() && stat->GetSymlinkData()->IsValid())
                                   text.Printf(wxT("-->%s"), stat->GetSymlinkDestination(true).c_str());
                                  else text = _(" *** Broken symlink ***");
                               }
+                             else text.Clear(); // We don't want to display '?' just because it's not a link
         }    
     }
     
@@ -1724,6 +1734,35 @@ if (clientDC) delete clientDC;
 }
 #endif
 
+#if wxVERSION_NUMBER > 3102
+void MyTreeCtrl::Expand(const wxTreeItemId& itemId)  // Needed in wx3.2 as otherwise non-fulltree dirview roots don't get children added. See wx git a6b92cb313 and https://trac.wxwidgets.org/ticket/13886
+{
+wxGenericTreeItem *item = (wxGenericTreeItem*)itemId.m_pItem;
+
+wxCHECK_RET( item, wxT("invalid item in wxGenericTreeCtrl::Expand") );
+wxCHECK_RET( !HasFlag(wxTR_HIDE_ROOT) || itemId != GetRootItem(),
+              wxT("can't expand hidden root") );
+
+if (!item->HasPlus())    return;
+
+if (item->IsExpanded())  return;
+
+wxTreeEvent event(wxEVT_TREE_ITEM_EXPANDING, this, item);
+if (GetEventHandler()->ProcessEvent( event ) && !event.IsAllowed())    return;    // cancelled by program
+
+item->Expand();
+if (!IsFrozen())
+  { CalculatePositions();
+    RefreshSubtree(item);
+  }
+else m_dirty = true;  // frozen
+
+event.SetEventType(wxEVT_TREE_ITEM_EXPANDED);
+GetEventHandler()->ProcessEvent(event);
+}
+
+#endif
+
 BEGIN_EVENT_TABLE(MyTreeCtrl,wxTreeCtrl)
     EVT_KEY_DOWN(MyTreeCtrl::AdjustForNumlock)
     EVT_SET_FOCUS(MyTreeCtrl::OnReceivingFocus)
@@ -1876,9 +1915,7 @@ pt.x += 1; // +1 to prevent very small bitmaps from touching the pointer and imm
 m_Popup->Position(pt, wxSize(0, -ps.GetHeight()));
 
 m_Popup->Popup(m_Tree);
-#if wxVERSION_NUMBER < 2900 || defined(__WXGTK3__)
-  m_Popup->SetSize(m_Popup->GetPanelSize()); // It doesn't size properly otherwise
-#endif
+m_Popup->SetSize(m_Popup->GetPanelSize()); // Otherwise it doesn't seem to know its size
 }
 
 PreviewPopup::PreviewPopup(wxWindow* parent) : wxPopupTransientWindow(parent), m_CanDisplay(false), m_Size(wxSize())
@@ -1890,6 +1927,8 @@ if (IsText(filepath)) // Try for text first: *.c files seem to return true from
   { DisplayText(filepath); m_CanDisplay = true; }
  else if (IsImage(filepath))
   { DisplayImage(filepath); m_CanDisplay = true; }
+
+Bind(wxEVT_LEAVE_WINDOW, &PreviewPopup::OnLeavingWindow, this);
 }
 
 bool PreviewPopup::IsImage(const wxString& filepath)
@@ -1897,6 +1936,7 @@ bool PreviewPopup::IsImage(const wxString& filepath)
 wxCHECK_MSG(!filepath.empty(), false, wxT("An empty filepath passed to IsImage()"));
 wxLogNull NoErrorMessages;
 
+if (filepath.Right(4) == ".svg") return true;
 return (wxImage::CanRead(filepath));
 }
 
@@ -1924,11 +1964,27 @@ delete ft;
 return result;
 }
 
-void PreviewPopup::DisplayImage(const wxString& filepath)
+void PreviewPopup::DisplayImage(const wxString& fpath)
 {
 wxLogNull NoErrorMessages;
+wxString filepath(fpath);
+wxString pngfilepath;
+wxImage image;
+
+if (filepath.Right(4) == ".svg")
+  { void* handle = wxGetApp().GetRsvgHandle();
+    if (!handle) return; // Presumably librsvg is not available at present
+    
+    wxFileName fn(filepath); // Create a filepath in /tmp/ to store the .png
+    pngfilepath = "/tmp/" + fn.GetName() + ".png";
+    if (SvgToPng(filepath, pngfilepath, handle))
+      image = wxImage(pngfilepath);
+    wxRemoveFile(pngfilepath);
+  }
+ else
+   image = wxImage(filepath);
+
 
-wxImage image(filepath);
 if (!image.IsOk()) return;
 
 int ht = wxMin(image.GetHeight(), PreviewManager::MAX_PREVIEW_IMAGE_HT);
@@ -1959,6 +2015,7 @@ m_Size = wxSize(wt,ht);
 
 void PreviewPopup::DisplayText(const wxString& filepath)
 {
+wxLogNull NoErrorMessages;
 wxPanel* toppanel = new wxPanel(this, wxID_ANY);
 toppanel->SetBackgroundColour(*wxLIGHT_GREY);
 
@@ -1988,3 +2045,8 @@ toppanel->SetClientSize(wxSize(PreviewManager::MAX_PREVIEW_TEXT_WT,PreviewManage
 
 m_Size = wxSize(PreviewManager::MAX_PREVIEW_TEXT_WT, PreviewManager::MAX_PREVIEW_TEXT_HT);
 }
+
+void PreviewPopup::OnLeavingWindow(wxMouseEvent& event)
+{
+PreviewManager::ClearIfNotInside();
+}
