@@ -3,7 +3,7 @@
 // Purpose:    Undo-redo and manager
 // Part of:    4Pane
 // Author:     David Hart
-// Copyright:  (c) 2016 David Hart
+// Copyright:  (c) 2019 David Hart
 // Licence:    wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
 
@@ -222,7 +222,7 @@ Supercluster=false;
 //static
 bool UnRedoManager::AddEntry(UnRedo *newentry)  // Adds a new undoable action to the array
 {
-if (!ClusterIsOpen) { //wxLogError(_("Oops, we're trying to add to a cluster when none is open!?")); // which also should never ever happen
+if (!ClusterIsOpen) {// wxLogError(_("Oops, we're trying to add to a cluster when none is open!?")); // which also should never ever happen
                       StartCluster(); // Start one anyway, otherwise we'll always get the wxLogError
                     }
 
@@ -781,7 +781,7 @@ if (!UndoPossible) return false;
 bool result = CheckDupRen::ChangeLinkTarget(linkname, oldtarget);
 
 if (result)
-  MyFrame::mainframe->OnUpdateTrees(linkname.BeforeLast(wxFILE_SEP_PATH), IDs);
+  MyFrame::mainframe->OnUpdateTrees(linkname.BeforeLast(wxFILE_SEP_PATH), IDs, "", true); // 'true' forces a refresh in case the symlink icon needs to change to/from broken
 
 if (result)  DoBriefLogStatus(1, _("action"),  _(" undone"));
 return result;
@@ -794,7 +794,7 @@ if (!RedoPossible) return false;
 bool result = CheckDupRen::ChangeLinkTarget(linkname, newtarget);
 
 if (result)
-  MyFrame::mainframe->OnUpdateTrees(linkname.BeforeLast(wxFILE_SEP_PATH), IDs);
+  MyFrame::mainframe->OnUpdateTrees(linkname.BeforeLast(wxFILE_SEP_PATH), IDs, "", true);
 
 if (result)  DoBriefLogStatus(1, _("action"),  _(" redone"));
 return result;
